Authors
=========

* Christopher Glass
* Stefan Foulis
* Juande Carrion
* Filip Wasilewski

Previous authors
=================

Some code in this project is left from the project it was forked from, so previous authors include:

* J. Javier Maestro
* Miguel Araujo

Please refer to https://github.com/maraujop/django-rules/ for a more complete list

